# FHIRGuard

FHIRGuard is a Python library that validates FHIR resources using SIMPLIFIER.NET packages.

## Credits

© Copyright HL7® logo, FHIR® logo and the flaming fire are registered trademarks owned by [Health Level Seven International](https://www.hl7.org/legal/trademarks.cfm).
